==> haskell-managed-1.0.5-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.5
id: managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE
key: managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE
license: BSD3
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
abi: 15b995d4dd0816866315060d33aab390
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/managed-1.0.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/managed-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/managed-1.0.5
hs-libraries: HSmanaged-1.0.5-AtVs0QEjn5cnY7UxRWyLE
depends:
    base-4.10.0.0 transformers-0.5.2.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-managed-1.0.5-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: managed
version: 1.0.5
id: managed-1.0.5-JwPhzVcLbN636Xkdl8jbtP
key: managed-1.0.5-JwPhzVcLbN636Xkdl8jbtP
license: BSD3
copyright: 2014 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.
    .
    The reason this package defines a specialized version of these types is to:
    .
    * be more beginner-friendly,
    .
    * simplify inferred types and error messages, and:
    .
    * provide some additional type class instances that would otherwise be orphan
    instances
category: Control
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Managed Control.Monad.Managed.Safe
abi: 6ed7064eb493038acf26295ab9a83f62
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/managed-1.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/managed-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/managed-1.0.5
hs-libraries: HSmanaged-1.0.5-JwPhzVcLbN636Xkdl8jbtP
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html: /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
